@@ -3,7 +3,7 @@ var _ref,
   __extends = function(child, parent) { for (var key in parent) { if (__hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor; child.__super__ = parent.prototype; return child; };
 
 window.cldoc = $.extend($.extend({
-  host: document.location.origin + '/' + document.location.pathname.substring(0, document.location.pathname.lastIndexOf('/'))
+  host: document.location.href.substring(0, document.location.href.lastIndexOf('/'))
 }, (_ref = window.cldoc) != null ? _ref : {}), {
   tag: function(node) {
     return $.map(node, function(e) {
@@ -397,7 +397,7 @@ cldoc.Page = (function() {
       page = m[1];
       scrollto = m[3];
     }
-    return $(window).on('popstate', function(e) {
+    $(window).on('popstate', function(e) {
       var state;
       if (e.originalEvent.state) {
         state = e.originalEvent.state;
@@ -406,10 +406,9 @@ cldoc.Page = (function() {
         } else {
           return _this.select(state.scrollto);
         }
-      } else {
-        return _this.load(page, scrollto);
       }
     });
+    return this.load(page, scrollto);
   };
 
   Page.select = function(scrollto, doanimate) {
